Gets the pathname of the currently running startup script
Source:R/current_script.R
current_script.RdGets the pathname of the currently running startup script
R/current_script.R
current_script.RdGets the pathname of the currently running startup script