Produce a warning
Arguments
- ..., domain
The message and optionally the domain used for translation. The ... arguments are passed to base::sprintf to create the message string.
- call.
If base::TRUE, the call is included in the warning message, otherwise not.
- immediate.
If base::TRUE, the warning is outputted immediately, otherwise not.