Record R session information as options
Source:R/startup_session_options.R
startup_session_options.RdRecord R session information as options
Usage
startup_session_options(action = c("update", "overwrite", "erase"))Value
Returns invisibly a named list of the options prefixed
"startup.session.":
startup.session.startdir(character) the working directory when the startup was first loaded. If
startup::startup()is called at the very beginning of the.Rprofilefile, this is also the directory that the current R session was launched from.startup.session.starttime(POSIXct) the time when the startup was first loaded.
startup.session.id(character) a unique ID for the current R session.
startup.session.dumpto(character) a session-specific name that can be used for argument
dumptoof dump.frames() (also for dumping to file).
Examples
opts <- startup::startup_session_options()
opts
#> $startup.session.startdir
#> [1] "/tmp/hb/RtmpjTDzAi/startup"
#>
#> $startup.session.starttime
#> [1] "2026-02-27 16:26:40 PST"
#>
#> $startup.session.starttime_iso
#> [1] "20260227-162640"
#>
#> $startup.session.id
#> [1] "RtmpbvVlcs"
#>
#> $startup.session.dumpto
#> [1] "/tmp/hb/RtmpjTDzAi/startup/last.dump_20260227-162640_RtmpbvVlcs"
#>